@@ -5,18 +5,19 @@
 #' It is based on aggregations of the census tracts from the Brazilian
 #' census. Only 2010 data is currently available.
 #'
-#' @param year Year of the data. Defaults to `2010`
+#' @param year Numeric. Year of the data in YYYY format. Defaults to `2010`.
 #' @template simplified
 #' @template showProgress
 #'
 #' @return An `"sf" "data.frame"` object
 #'
 #' @export
-#' @family general area functions
-#' @examples \dontrun{ if (interactive()) {
+#' @family area functions
+#'
+#' @examplesIf identical(tolower(Sys.getenv("NOT_CRAN")), "true")
 #' # Read neighborhoods of Brazilian municipalities
 #' n <- read_neighborhood(year=2010)
-#'}}
+#'
 read_neighborhood <- function(year=2010, simplified=TRUE, showProgress=TRUE){
 
   # Get metadata with data url addresses
@@ -27,5 +28,9 @@ read_neighborhood <- function(year=2010, simplified=TRUE, showProgress=TRUE){
 
   # download files
   temp_sf <- download_gpkg(file_url, progress_bar = showProgress)
+
+  # check if download failed
+  if (is.null(temp_sf)) { return(invisible(NULL)) }
+
   return(temp_sf)
 }
