@@ -1,9 +1,8 @@
 context("read_census_tract")
 
 # skip tests because they take too much time
-# skip_if(Sys.getenv("TEST_ONE") != "")
+skip_if(Sys.getenv("TEST_ONE") != "")
 testthat::skip_on_cran()
-# testthat::skip_on_travis()
 
 
 test_that("read_census_tract", {
